@@ -2,21 +2,21 @@
 #
 #PBS -N job_3
 
-#PBS -l nodes=1:ppn=12
+#PBS -l nodes=1:ppn=4
 
-#PBS -l walltime=15:00:00
+#PBS -l walltime=04:00:00
 
 #PBS -j oe
-#PBS -o localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_18T05_33_19/job_3.log
+#PBS -o localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_25T05_51_18/job_3.log
+
+#PBS -l mem=24GB
 
 
 
 
-#MY SPECIAL TEMPLATE
-
 
     
-module load jdk/1.8.0_35
+module load module1
     
 
 
