@@ -21,7 +21,7 @@ extends 'HPC::Runner';
 extends 'HPC::Runner::Slurm';
 with 'MooseX::SimpleConfig';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
@@ -254,6 +254,8 @@ sub submit_slurm{
 
     #($jobid) = $stdout =~ m/(\w.*)$/ if $stdout;
     ($jobid) = $stdout;
+    chomp($jobid);
+
     if(!$jobid){
         print "No job was submitted! Please check your things!\nFull error is:\t$stderr\n$stdout\nEnd Job error";
         print "Submit scripts will be written, but will not be submitted to the queue. Please look at your files in ".$self->outdir." for more information\n";
@@ -263,6 +265,8 @@ sub submit_slurm{
         push(@{$self->jobref->[-1]}, $jobid);
         print "Submitting job ".$self->slurmfile."\n\tWith PBS jobid $jobid\n";
     }
+    #Fix for jobs not showing up...
+    sleep(5);
 }
 
 
